(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/platform-browser'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('@covalent/highlight', ['exports', '@angular/core', '@angular/platform-browser', '@angular/common'], factory) :
    (global = global || self, factory((global.covalent = global.covalent || {}, global.covalent.highlight = {}), global.ng.core, global.ng.platformBrowser, global.ng.common));
}(this, (function (exports, core, platformBrowser, common) { 'use strict';

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    /* tslint:disable-next-line */
    /** @type {?} */
    var hljs = require('highlight.js/lib');
    var TdHighlightComponent = /** @class */ (function () {
        function TdHighlightComponent(_renderer, _elementRef, _domSanitizer) {
            this._renderer = _renderer;
            this._elementRef = _elementRef;
            this._domSanitizer = _domSanitizer;
            this._initialized = false;
            /**
             * lang?: string
             *
             * Language of the code content to be parsed as highlighted html.
             * Defaults to `typescript`
             *
             * e.g. `typescript`, `html` , etc.
             */
            this.lang = 'typescript';
            /**
             * contentReady?: function
             * Event emitted after the highlight content rendering is finished.
             */
            this.contentReady = new core.EventEmitter();
        }
        Object.defineProperty(TdHighlightComponent.prototype, "content", {
            /**
             * content?: string
             *
             * Code content to be parsed as highlighted html.
             * Used to load data dynamically.
             *
             * e.g. `.html`, `.ts` , etc.
             */
            set: /**
             * content?: string
             *
             * Code content to be parsed as highlighted html.
             * Used to load data dynamically.
             *
             * e.g. `.html`, `.ts` , etc.
             * @param {?} content
             * @return {?}
             */
            function (content) {
                this._content = content;
                if (this._initialized) {
                    this._loadContent(this._content);
                }
            },
            enumerable: true,
            configurable: true
        });
        /**
         * @return {?}
         */
        TdHighlightComponent.prototype.ngAfterViewInit = /**
         * @return {?}
         */
        function () {
            if (!this.lang) {
                throw new Error('Error: language attribute must be defined in TdHighlightComponent.');
            }
            if (!this._content) {
                this._loadContent(((/** @type {?} */ (this._elementRef.nativeElement))).textContent);
            }
            else {
                this._loadContent(this._content);
            }
            this._initialized = true;
        };
        /**
         * General method to parse a string of code into HTML Elements and load them into the container
         */
        /**
         * General method to parse a string of code into HTML Elements and load them into the container
         * @private
         * @param {?} code
         * @return {?}
         */
        TdHighlightComponent.prototype._loadContent = /**
         * General method to parse a string of code into HTML Elements and load them into the container
         * @private
         * @param {?} code
         * @return {?}
         */
        function (code) {
            if (code && code.trim().length > 0) {
                // Clean container
                this._renderer.setProperty(this._elementRef.nativeElement, 'innerHTML', '');
                // Parse html string into actual HTML elements.
                this._elementFromString(this._render(code));
            }
            this.contentReady.emit();
        };
        /**
         * @private
         * @param {?} codeStr
         * @return {?}
         */
        TdHighlightComponent.prototype._elementFromString = /**
         * @private
         * @param {?} codeStr
         * @return {?}
         */
        function (codeStr) {
            // Renderer2 doesnt have a parsing method, so we have to sanitize and use [innerHTML]
            // to parse the string into DOM element for now.
            /** @type {?} */
            var preElement = this._renderer.createElement('pre');
            this._renderer.appendChild(this._elementRef.nativeElement, preElement);
            /** @type {?} */
            var codeElement = this._renderer.createElement('code');
            this._renderer.appendChild(preElement, codeElement);
            // Set .highlight class into <code> element
            this._renderer.addClass(codeElement, 'highlight');
            codeElement.innerHTML = this._domSanitizer.sanitize(core.SecurityContext.HTML, codeStr);
            return preElement;
        };
        /**
         * @private
         * @param {?} contents
         * @return {?}
         */
        TdHighlightComponent.prototype._render = /**
         * @private
         * @param {?} contents
         * @return {?}
         */
        function (contents) {
            // Trim leading and trailing newlines
            contents = contents.replace(/^(\s|\t)*\n+/g, '').replace(/(\s|\t)*\n+(\s|\t)*$/g, '');
            // Split markup by line characters
            /** @type {?} */
            var lines = contents.split('\n');
            // check how much indentation is used by the first actual code line
            /** @type {?} */
            var firstLineWhitespace = lines[0].match(/^(\s|\t)*/)[0];
            // Remove all indentation spaces so code can be parsed correctly
            /** @type {?} */
            var startingWhitespaceRegex = new RegExp('^' + firstLineWhitespace);
            lines = lines.map((/**
             * @param {?} line
             * @return {?}
             */
            function (line) {
                return line
                    .replace('=""', '') // remove empty values
                    .replace(startingWhitespaceRegex, '')
                    .replace(/\s+$/, ''); // remove trailing white spaces
            }));
            /** @type {?} */
            var codeToParse = lines
                .join('\n')
                .replace(/\{ \{/gi, '{{')
                .replace(/\} \}/gi, '}}')
                .replace(/&lt;/gi, '<')
                .replace(/&gt;/gi, '>');
            // replace with < and > to render HTML in Angular
            // Parse code with highlight.js depending on language
            /** @type {?} */
            var highlightedCode = hljs.highlight(this.lang, codeToParse, true);
            highlightedCode.value = highlightedCode.value
                .replace(/=<span class="hljs-value">""<\/span>/gi, '')
                .replace('<head>', '')
                .replace('<head/>', '');
            return highlightedCode.value;
        };
        TdHighlightComponent.decorators = [
            { type: core.Component, args: [{
                        selector: 'td-highlight',
                        template: "<ng-content></ng-content>\n",
                        styles: [":host ::ng-deep{display:block;overflow-x:auto;padding:16px}:host ::ng-deep .highlight,:host ::ng-deep code,:host ::ng-deep pre{font-family:Menlo,Monaco,\"Andale Mono\",\"lucida console\",\"Courier New\",monospace}:host ::ng-deep pre{display:block;overflow-x:auto;padding:0;margin:0;background:0 0;font-family:Menlo,Monaco,\"Andale Mono\",\"lucida console\",\"Courier New\",monospace;line-height:1.45;-moz-tab-size:2;-o-tab-size:2;tab-size:2;-webkit-font-smoothing:auto;-webkit-text-size-adjust:none;position:relative;border-radius:2px;font-size:.8rem}:host ::ng-deep code{margin:0;padding:0;overflow-wrap:break-word;white-space:pre-wrap}:host ::ng-deep .highlight{display:block;overflow-wrap:break-word;line-height:1.5;margin:0}"]
                    }] }
        ];
        /** @nocollapse */
        TdHighlightComponent.ctorParameters = function () { return [
            { type: core.Renderer2 },
            { type: core.ElementRef },
            { type: platformBrowser.DomSanitizer }
        ]; };
        TdHighlightComponent.propDecorators = {
            content: [{ type: core.Input, args: ['content',] }],
            lang: [{ type: core.Input }],
            contentReady: [{ type: core.Output }]
        };
        return TdHighlightComponent;
    }());
    if (false) {
        /**
         * @type {?}
         * @private
         */
        TdHighlightComponent.prototype._initialized;
        /**
         * @type {?}
         * @private
         */
        TdHighlightComponent.prototype._content;
        /**
         * lang?: string
         *
         * Language of the code content to be parsed as highlighted html.
         * Defaults to `typescript`
         *
         * e.g. `typescript`, `html` , etc.
         * @type {?}
         */
        TdHighlightComponent.prototype.lang;
        /**
         * contentReady?: function
         * Event emitted after the highlight content rendering is finished.
         * @type {?}
         */
        TdHighlightComponent.prototype.contentReady;
        /**
         * @type {?}
         * @private
         */
        TdHighlightComponent.prototype._renderer;
        /**
         * @type {?}
         * @private
         */
        TdHighlightComponent.prototype._elementRef;
        /**
         * @type {?}
         * @private
         */
        TdHighlightComponent.prototype._domSanitizer;
    }

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var CovalentHighlightModule = /** @class */ (function () {
        function CovalentHighlightModule() {
        }
        CovalentHighlightModule.decorators = [
            { type: core.NgModule, args: [{
                        imports: [common.CommonModule],
                        declarations: [TdHighlightComponent],
                        exports: [TdHighlightComponent],
                    },] }
        ];
        return CovalentHighlightModule;
    }());

    exports.CovalentHighlightModule = CovalentHighlightModule;
    exports.TdHighlightComponent = TdHighlightComponent;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=covalent-highlight.umd.js.map
